---
feature_story: FS_14_59_14_06
feature_title: pending requests
feature_status: TEST
---

This feature splits client into two OS processes:
*   parent to control user interaction
*   child to wait for pending request

The initial motivation was to provide indication (spinner) of long-running request to the user.<br/>
But it can be extended to handle switch over to another server in case of server unavailability, etc.

# Spinner

The spinner is only used for:
*   `ServerAction.ProposeArgValues` = Tab
*   `ServerAction.DescribeLineArgs` = Alt+Shift+Q
Specifically, `ServerAction.RelayLineArgs` simply blocks within the same OS process until requests completes.

The spinner is enabled by default. To disable it, set `ClientConfig.show_pending_spinner` to `False`.
